@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # synadm
 # Copyright (C) 2020-2025 Johannes Tiefenbacher
+# Copyright (C) 2023-2025 JacksonChen666
 #
 # claradm is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -631,9 +632,95 @@ class SynapseAdmin(ApiRequest):
             string: JSON string containing the Admin API's response or None if
                 an exception occured. See Synapse Admin API docs for details.
         """
-        return self.query(
-            "post", "v1/deactivate/{user_id}", data={"erase": gdpr_erase}, user_id=user_id
-        )
+        return self.query("post", "v1/deactivate/{user_id}", data={
+            "erase": gdpr_erase
+        }, user_id=user_id)
+
+    def user_suspend(self, user_id):
+        """
+        Suspend an account to prevent it from doing anything, essentially
+        freezing it.
+
+        To query the status, use the user_details function or the Query User
+        Account API
+        (https://element-hq.github.io/synapse/latest/admin_api/user_admin_api.html#query-user-account).
+
+        https://element-hq.github.io/synapse/latest/admin_api/user_admin_api.html#suspendunsuspend-account
+
+        Args:
+            user_id (string): fully qualified Matrix user ID
+
+        Returns:
+            string: JSON string containing the Admin API's response or None if
+            an exception occured. See Synapse Admin API docs for details.
+        """
+        data = {"suspend": True}
+        return self.query("PUT", "v1/suspend/{user_id}", data=data,
+                          user_id=user_id)
+
+    def user_unsuspend(self, user_id):
+        """
+        Unsuspend an account to prevent it from doing anything.
+
+        To query the status, use the user_details function or the Query User
+        Account API
+        (https://element-hq.github.io/synapse/latest/admin_api/user_admin_api.html#query-user-account).
+
+        https://element-hq.github.io/synapse/latest/admin_api/user_admin_api.html#suspendunsuspend-account
+
+        Args:
+            user_id (string): fully qualified Matrix user ID
+
+        Returns:
+            string: JSON string containing the Admin API's response or None if
+            an exception occured. See Synapse Admin API docs for details.
+        """
+        data = {"suspend": False}
+        return self.query("PUT", "v1/suspend/{user_id}", data=data,
+                          user_id=user_id)
+
+    def user_suspend(self, user_id):
+        """
+        Suspend an account to prevent it from doing anything, essentially
+        freezing it.
+
+        To query the status, use the user_details function or the Query User
+        Account API
+        (https://element-hq.github.io/synapse/latest/admin_api/user_admin_api.html#query-user-account).
+
+        https://element-hq.github.io/synapse/latest/admin_api/user_admin_api.html#suspendunsuspend-account
+
+        Args:
+            user_id (string): fully qualified Matrix user ID
+
+        Returns:
+            string: JSON string containing the Admin API's response or None if
+            an exception occured. See Synapse Admin API docs for details.
+        """
+        data = {"suspend": True}
+        return self.query("PUT", "v1/suspend/{user_id}", data=data,
+                          user_id=user_id)
+
+    def user_unsuspend(self, user_id):
+        """
+        Unsuspend an account to prevent it from doing anything.
+
+        To query the status, use the user_details function or the Query User
+        Account API
+        (https://element-hq.github.io/synapse/latest/admin_api/user_admin_api.html#query-user-account).
+
+        https://element-hq.github.io/synapse/latest/admin_api/user_admin_api.html#suspendunsuspend-account
+
+        Args:
+            user_id (string): fully qualified Matrix user ID
+
+        Returns:
+            string: JSON string containing the Admin API's response or None if
+            an exception occured. See Synapse Admin API docs for details.
+        """
+        data = {"suspend": False}
+        return self.query("PUT", "v1/suspend/{user_id}", data=data,
+                          user_id=user_id)
 
     def user_password(self, user_id, password, no_logout):
         """Set the user password, and log the user out if requested
@@ -718,7 +805,7 @@ class SynapseAdmin(ApiRequest):
 
     def user_modify(
         self, user_id, password, display_name, threepid, avatar_url, admin, deactivation, user_type,
-        lock, logout_devices
+        lock, logout_devices, external_ids=(),
     ):
         """ Create or update information about a given user
 
@@ -749,6 +836,10 @@ class SynapseAdmin(ApiRequest):
             data.update({"user_type": None if user_type == 'null' else user_type})
         if logout_devices:
             data.update({"logout_devices": logout_devices})
+        if external_ids:
+            data.update({"external_ids": [
+                {"auth_provider": k, "external_id": i} for k, i in dict(external_ids).items()
+            ]})
         return self.query("put", "v2/users/{user_id}", data=data, user_id=user_id)
 
     def user_whois(self, user_id):
@@ -1479,8 +1570,9 @@ class SynapseAdmin(ApiRequest):
         """
         # t because query also accepts token when we want it for the
         # request
-        # https://github.com/JOJ0/synadm/issues/110#issuecomment-1590032158
-        return self.query("delete", "v1/registration_tokens/{t}", t=token)
+        # https://codeberg.org/synadm/synadm/issues/110#issuecomment-3112443
+        return self.query("delete", "v1/registration_tokens/{t}",
+                          t=token)
 
     def user_shadow_ban(self, user_id, unban):
         """ Shadow-ban or unban a user.
