@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # claradm
 # Copyright (C) 2020-2025 Johannes Tiefenbacher
+# Copyright (C) 2023-2025 JacksonChen666
 #
 # claradm is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -986,3 +987,38 @@ def third_party_id_search(helper, medium, address):
     of Third Party ID that is used such as 'email' or 'msidn'.
     """
     helper.output(helper.api.user_3pid_search(medium, address))
+
+
+@user.command()
+@click.argument("user_id")
+@click.option(
+    "--unsuspend/-U", type=bool, is_flag=True,
+    help="""Undo a suspension"""
+)
+@click.pass_obj
+def suspend(helper, user_id, unsuspend):
+    """
+    Prevent an account from doing anything
+
+    This essentially freezes an account, preventing an account from sending
+    invites, joining rooms, knocking on rooms, sending messages, changing
+    profile data, and redacting other's messages (own messages can be
+    redacted).
+
+    To query whether an account is suspended, use the `synadm user details`
+    command.
+    """
+    mxid = helper.generate_mxid(user_id)
+    sure = (
+        helper.no_confirm or
+        click.prompt(
+            "Are you sure you want to {} {}? (y/N)"
+            .format(("unsuspend" if unsuspend else "suspend"), mxid),
+            type=bool, default=False, show_default=False)
+    )
+    if sure:
+        if unsuspend:
+            result = helper.api.user_unsuspend(mxid)
+        else:
+            result = helper.api.user_suspend(mxid)
+        helper.output(result)
