@@ -17,10 +17,8 @@ from .dict_utils import get_nested_key, set_nested_key
 from .ini_cfg import BaseDirectoryConfig, DirectoryEmail, DirectoryGeneral
 from .typehints import DerivedField
 
-
 import sys
 
-
 FILE_PATH = Union[str, Path]
 
 
@@ -114,7 +112,8 @@ class ClaradmYAML(YAML):
             inefficient = True
             stream = StringIO()
 
-        ruamel.yaml.dump(data, stream, Dumper=RoundTripDumper, **kwargs)
+        yaml = YAML()
+        yaml.dump(data, stream, **kwargs)
 
         if inefficient:
             return stream.getvalue()
@@ -154,7 +153,6 @@ class ClaradmYAML(YAML):
                 self._all_config_data.update(**dict(ConfigClass().load_config()))
 
             # If default values aren't set for derived fields, specify them here.
-            print(self._all_config_data)
             for field in self.DERIVED_FIELDS:
                 current_value = get_nested_key(self._all_config_data, field.name)
                 if current_value and not field.overwrite:
@@ -198,7 +196,10 @@ class HomeServerConfig(ClaradmYAML):
     DERIVED_FIELDS = (
         DerivedField('server_name', '{subdomain}.{clarion_service}', True),
         DerivedField('public_baseurl', 'https://{subdomain}.{clarion_service}', True),
-        DerivedField('signing_key_path', '/etc/clarion/homeserver/{subdomain}.{clarion_service}.signing.key', False),
+        DerivedField(
+            'signing_key_path', '/etc/clarion/homeserver/{subdomain}.{clarion_service}.signing.key',
+            False
+        ),
     )
     DIRECTORY_SERVER_CLASSES = [
         DirectoryGeneral,
@@ -225,6 +226,7 @@ class HomeServerConfig(ClaradmYAML):
             "m.identity_server": {
                 "base_url": f"https://{subdomain}.clarion.directory",
             },
+            "org.matrix.msc3814": "true",
         }
         with open(f'{WEB_ROOT}/well_known_client.json', 'w') as wkj:
             json.dump(server, wkj, indent=2)
@@ -234,9 +236,7 @@ class HomeServerConfig(ClaradmYAML):
         Save well-known json files for server.
         """
         cfg_data = self._all_config_data
-        server = {
-            "m.server": f'{cfg_data["subdomain"]}.{cfg_data["clarion_service"]}'
-        }
+        server = {"m.server": f'{cfg_data["subdomain"]}.{cfg_data["clarion_service"]}'}
         with open(f'{WEB_ROOT}/well_known_server.json', 'w') as wkj:
             json.dump(server, wkj, indent=2)
 
@@ -273,8 +273,7 @@ class HomeServerConfig(ClaradmYAML):
             "default_federate": False,
             "default_theme": "light",
             "room_directory": {
-                "servers": [
-                ],
+                "servers": [],
             },
             "enable_presence_by_hs_url": {
                 f"https://{server_name}": True,
@@ -307,11 +306,11 @@ class EmailConfig(ClaradmYAML):
     DERIVED_FIELDS = (
         DerivedField('email:app_name', 'Clarion {entity_name}', True),
         DerivedField('email:smtp_user', '{subdomain}@clarion.im', True),
-        DerivedField('email:notif_from', 'Clarion for {entity_name} <{subdomain}@clarion.im>', True),
-    )
-    SECRETS_FIELDS = (
-        ('email:smtp_pass', 'SMTP password', token_urlsafe),
+        DerivedField(
+            'email:notif_from', 'Clarion for {entity_name} <{subdomain}@clarion.im>', True
+        ),
     )
+    SECRETS_FIELDS = (('email:smtp_pass', 'SMTP password', token_urlsafe),)
     DIRECTORY_SERVER_CLASSES = [
         DirectoryEmail,
     ]
@@ -324,7 +323,10 @@ class FederationConfig(ClaradmYAML):
     CONFIG_FILE = 'federation.yaml'
     FIELDS = (
         ('allow_profile_lookup_over_federation', 'Allow Profile Lookup Over Federation', True),
-        ('allow_device_name_lookup_over_federation', 'Allow Device Name Lookup Over Federation', True),
+        (
+            'allow_device_name_lookup_over_federation', 'Allow Device Name Lookup Over Federation',
+            True
+        ),
     )
 
 
@@ -334,7 +336,10 @@ class MaintenanceConfig(ClaradmYAML):
     """
     CONFIG_FILE = 'maintenance.yaml'
     FIELDS = (
-        ('background_updates:background_update_duration_ms', 'Background Update Duration in milliseconds', 500),
+        (
+            'background_updates:background_update_duration_ms',
+            'Background Update Duration in milliseconds', 500
+        ),
         ('background_updates:sleep_enabled', 'Sleep Enabled', True),
         ('background_updates:sleep_duration_ms', 'Sleep Duration', 1000),
         ('background_updates:min_batch_size', 'Minimum Batch Size', 10),
@@ -486,7 +491,10 @@ class RegistrationConfig(ClaradmYAML):
     CONFIG_FILE = 'registration.yaml'
     FIELDS = (
         ('enable_registration', 'Enable account registration on this server', False),
-        ('enable_registration_without_verification', 'Enable account registration without verification', False),
+        (
+            'enable_registration_without_verification',
+            'Enable account registration without verification', False
+        ),
         ('session_lifetime', 'Session lifetime', '48h'),
         ('refreshable_access_token_lifetime', 'Refreshable access token lifetime', '30m'),
         ('refresh_token_lifetime', 'Refresh token lifetime', '48h'),
